==> percona-server-mongodb_4.4.1.orig.tar.gz: percona-server-mongodb-4.4.1-2/aws-sdk-cpp/aws-cpp-sdk-monitoring/source/model/MetricDataQuery.cpp <==
﻿/*
* Copyright 2010-2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
*
* Licensed under the Apache License, Version 2.0 (the "License").
* You may not use this file except in compliance with the License.
* A copy of the License is located at
*
*  http://aws.amazon.com/apache2.0
*
* or in the "license" file accompanying this file. This file is distributed
* on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
* express or implied. See the License for the specific language governing
* permissions and limitations under the License.
*/

#include <aws/monitoring/model/MetricDataQuery.h>
#include <aws/core/utils/xml/XmlSerializer.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Utils::Xml;
using namespace Aws::Utils;

namespace Aws
{
namespace CloudWatch
{
namespace Model
{

MetricDataQuery::MetricDataQuery() : 
    m_idHasBeenSet(false),
    m_metricStatHasBeenSet(false),
    m_expressionHasBeenSet(false),
    m_labelHasBeenSet(false),
    m_returnData(false),
    m_returnDataHasBeenSet(false)
{
}

MetricDataQuery::MetricDataQuery(const XmlNode& xmlNode) : 
    m_idHasBeenSet(false),
    m_metricStatHasBeenSet(false),
    m_expressionHasBeenSet(false),
    m_labelHasBeenSet(false),
    m_returnData(false),
    m_returnDataHasBeenSet(false)
{
  *this = xmlNode;
}

MetricDataQuery& MetricDataQuery::operator =(const XmlNode& xmlNode)
{
  XmlNode resultNode = xmlNode;

  if(!resultNode.IsNull())
  {
    XmlNode idNode = resultNode.FirstChild("Id");
    if(!idNode.IsNull())
    {
      m_id = StringUtils::Trim(idNode.GetText().c_str());
      m_idHasBeenSet = true;
    }
    XmlNode metricStatNode = resultNode.FirstChild("MetricStat");
    if(!metricStatNode.IsNull())
    {
      m_metricStat = metricStatNode;
      m_metricStatHasBeenSet = true;
    }
    XmlNode expressionNode = resultNode.FirstChild("Expression");
    if(!expressionNode.IsNull())
    {
      m_expression = StringUtils::Trim(expressionNode.GetText().c_str());
      m_expressionHasBeenSet = true;
    }
    XmlNode labelNode = resultNode.FirstChild("Label");
    if(!labelNode.IsNull())
    {
      m_label = StringUtils::Trim(labelNode.GetText().c_str());
      m_labelHasBeenSet = true;
    }
    XmlNode returnDataNode = resultNode.FirstChild("ReturnData");
    if(!returnDataNode.IsNull())
    {
      m_returnData = StringUtils::ConvertToBool(StringUtils::Trim(returnDataNode.GetText().c_str()).c_str());
      m_returnDataHasBeenSet = true;
    }
  }

  return *this;
}

void MetricDataQuery::OutputToStream(Aws::OStream& oStream, const char* location, unsigned index, const char* locationValue) const
{
  if(m_idHasBeenSet)
  {
      oStream << location << index << locationValue << ".Id=" << StringUtils::URLEncode(m_id.c_str()) << "&";
  }

  if(m_metricStatHasBeenSet)
  {
      Aws::StringStream metricStatLocationAndMemberSs;
      metricStatLocationAndMemberSs << location << index << locationValue << ".MetricStat";
      m_metricStat.OutputToStream(oStream, metricStatLocationAndMemberSs.str().c_str());
  }

  if(m_expressionHasBeenSet)
  {
      oStream << location << index << locationValue << ".Expression=" << StringUtils::URLEncode(m_expression.c_str()) << "&";
  }

  if(m_labelHasBeenSet)
  {
      oStream << location << index << locationValue << ".Label=" << StringUtils::URLEncode(m_label.c_str()) << "&";
  }

  if(m_returnDataHasBeenSet)
  {
      oStream << location << index << locationValue << ".ReturnData=" << std::boolalpha << m_returnData << "&";
  }

}

void MetricDataQuery::OutputToStream(Aws::OStream& oStream, const char* location) const
{
  if(m_idHasBeenSet)
  {
      oStream << location << ".Id=" << StringUtils::URLEncode(m_id.c_str()) << "&";
  }
  if(m_metricStatHasBeenSet)
  {
      Aws::String metricStatLocationAndMember(location);
      metricStatLocationAndMember += ".MetricStat";
      m_metricStat.OutputToStream(oStream, metricStatLocationAndMember.c_str());
  }
  if(m_expressionHasBeenSet)
  {
      oStream << location << ".Expression=" << StringUtils::URLEncode(m_expression.c_str()) << "&";
  }
  if(m_labelHasBeenSet)
  {
      oStream << location << ".Label=" << StringUtils::URLEncode(m_label.c_str()) << "&";
  }
  if(m_returnDataHasBeenSet)
  {
      oStream << location << ".ReturnData=" << std::boolalpha << m_returnData << "&";
  }
}

} // namespace Model
} // namespace CloudWatch
} // namespace Aws

==> percona-server-mongodb-36_3.6.23.orig.tar.gz: percona-server-mongodb-3.6.23-13.0/aws-sdk-cpp/aws-cpp-sdk-monitoring/source/model/MetricDataQuery.cpp <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#include <aws/monitoring/model/MetricDataQuery.h>
#include <aws/core/utils/xml/XmlSerializer.h>
#include <aws/core/utils/StringUtils.h>
#include <aws/core/utils/memory/stl/AWSStringStream.h>

#include <utility>

using namespace Aws::Utils::Xml;
using namespace Aws::Utils;

namespace Aws
{
namespace CloudWatch
{
namespace Model
{

MetricDataQuery::MetricDataQuery() : 
    m_idHasBeenSet(false),
    m_metricStatHasBeenSet(false),
    m_expressionHasBeenSet(false),
    m_labelHasBeenSet(false),
    m_returnData(false),
    m_returnDataHasBeenSet(false),
    m_period(0),
    m_periodHasBeenSet(false)
{
}

MetricDataQuery::MetricDataQuery(const XmlNode& xmlNode) : 
    m_idHasBeenSet(false),
    m_metricStatHasBeenSet(false),
    m_expressionHasBeenSet(false),
    m_labelHasBeenSet(false),
    m_returnData(false),
    m_returnDataHasBeenSet(false),
    m_period(0),
    m_periodHasBeenSet(false)
{
  *this = xmlNode;
}

MetricDataQuery& MetricDataQuery::operator =(const XmlNode& xmlNode)
{
  XmlNode resultNode = xmlNode;

  if(!resultNode.IsNull())
  {
    XmlNode idNode = resultNode.FirstChild("Id");
    if(!idNode.IsNull())
    {
      m_id = Aws::Utils::Xml::DecodeEscapedXmlText(idNode.GetText());
      m_idHasBeenSet = true;
    }
    XmlNode metricStatNode = resultNode.FirstChild("MetricStat");
    if(!metricStatNode.IsNull())
    {
      m_metricStat = metricStatNode;
      m_metricStatHasBeenSet = true;
    }
    XmlNode expressionNode = resultNode.FirstChild("Expression");
    if(!expressionNode.IsNull())
    {
      m_expression = Aws::Utils::Xml::DecodeEscapedXmlText(expressionNode.GetText());
      m_expressionHasBeenSet = true;
    }
    XmlNode labelNode = resultNode.FirstChild("Label");
    if(!labelNode.IsNull())
    {
      m_label = Aws::Utils::Xml::DecodeEscapedXmlText(labelNode.GetText());
      m_labelHasBeenSet = true;
    }
    XmlNode returnDataNode = resultNode.FirstChild("ReturnData");
    if(!returnDataNode.IsNull())
    {
      m_returnData = StringUtils::ConvertToBool(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(returnDataNode.GetText()).c_str()).c_str());
      m_returnDataHasBeenSet = true;
    }
    XmlNode periodNode = resultNode.FirstChild("Period");
    if(!periodNode.IsNull())
    {
      m_period = StringUtils::ConvertToInt32(StringUtils::Trim(Aws::Utils::Xml::DecodeEscapedXmlText(periodNode.GetText()).c_str()).c_str());
      m_periodHasBeenSet = true;
    }
  }

  return *this;
}

void MetricDataQuery::OutputToStream(Aws::OStream& oStream, const char* location, unsigned index, const char* locationValue) const
{
  if(m_idHasBeenSet)
  {
      oStream << location << index << locationValue << ".Id=" << StringUtils::URLEncode(m_id.c_str()) << "&";
  }

  if(m_metricStatHasBeenSet)
  {
      Aws::StringStream metricStatLocationAndMemberSs;
      metricStatLocationAndMemberSs << location << index << locationValue << ".MetricStat";
      m_metricStat.OutputToStream(oStream, metricStatLocationAndMemberSs.str().c_str());
  }

  if(m_expressionHasBeenSet)
  {
      oStream << location << index << locationValue << ".Expression=" << StringUtils::URLEncode(m_expression.c_str()) << "&";
  }

  if(m_labelHasBeenSet)
  {
      oStream << location << index << locationValue << ".Label=" << StringUtils::URLEncode(m_label.c_str()) << "&";
  }

  if(m_returnDataHasBeenSet)
  {
      oStream << location << index << locationValue << ".ReturnData=" << std::boolalpha << m_returnData << "&";
  }

  if(m_periodHasBeenSet)
  {
      oStream << location << index << locationValue << ".Period=" << m_period << "&";
  }

}

void MetricDataQuery::OutputToStream(Aws::OStream& oStream, const char* location) const
{
  if(m_idHasBeenSet)
  {
      oStream << location << ".Id=" << StringUtils::URLEncode(m_id.c_str()) << "&";
  }
  if(m_metricStatHasBeenSet)
  {
      Aws::String metricStatLocationAndMember(location);
      metricStatLocationAndMember += ".MetricStat";
      m_metricStat.OutputToStream(oStream, metricStatLocationAndMember.c_str());
  }
  if(m_expressionHasBeenSet)
  {
      oStream << location << ".Expression=" << StringUtils::URLEncode(m_expression.c_str()) << "&";
  }
  if(m_labelHasBeenSet)
  {
      oStream << location << ".Label=" << StringUtils::URLEncode(m_label.c_str()) << "&";
  }
  if(m_returnDataHasBeenSet)
  {
      oStream << location << ".ReturnData=" << std::boolalpha << m_returnData << "&";
  }
  if(m_periodHasBeenSet)
  {
      oStream << location << ".Period=" << m_period << "&";
  }
}

} // namespace Model
} // namespace CloudWatch
} // namespace Aws
